pub struct MockProviderBillingApi {
ProviderBillingApi_expectations: MockProviderBillingApi_ProviderBillingApi,
}Fields
ProviderBillingApi_expectations: MockProviderBillingApi_ProviderBillingApiImplementations
Sourceimpl MockProviderBillingApi
impl MockProviderBillingApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockProviderBillingApi
impl MockProviderBillingApi
Sourcepub fn expect_generate_client_invoice_report(&mut self) -> &mut Expectation
pub fn expect_generate_client_invoice_report(&mut self) -> &mut Expectation
Create an Expectation for mocking the generate_client_invoice_report method
Sourcepub fn expect_get_invoices(&mut self) -> &mut Expectation
pub fn expect_get_invoices(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_invoices method
Sourcepub fn expect_get_subscription(&mut self) -> &mut Expectation
pub fn expect_get_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_subscription method